searchData={"items":[{"type":"module","title":"Phoenix.Template","doc":"Templates are markup languages that are compiled to Elixir code.\n\nThis module provides functions for loading and compiling templates\nfrom disk. A markup language is compiled to Elixir code via an engine.\nSee `Phoenix.Template.Engine`.\n\nIn practice, developers rarely use `Phoenix.Template` directly. Instead,\nlibraries such as `Phoenix.View` and `Phoenix.LiveView` use it as a\nbuilding block.","ref":"Phoenix.Template.html"},{"type":"module","title":"Custom Template Engines - Phoenix.Template","doc":"Phoenix supports custom template engines. Engines tell\nPhoenix how to convert a template path into quoted expressions.\nSee `Phoenix.Template.Engine` for more information on\nthe API required to be implemented by custom engines.\n\nOnce a template engine is defined, you can tell Phoenix\nabout it via the template engines option:\n\n    config :phoenix, :template_engines,\n      eex: Phoenix.Template.EExEngine,\n      exs: Phoenix.Template.ExsEngine","ref":"Phoenix.Template.html#module-custom-template-engines"},{"type":"module","title":"Format encoders - Phoenix.Template","doc":"Besides template engines, Phoenix has the concept of format encoders.\nFormat encoders work per format and are responsible for encoding a\ngiven format to a string. For example, when rendering JSON, your\ntemplates may return a regular Elixir map. Then the JSON format\nencoder is invoked to convert it to JSON.\n\nA format encoder must export a function called `encode_to_iodata!/1`\nwhich receives the rendering artifact and returns iodata.\n\nNew encoders can be added via the format encoder option:\n\n    config :phoenix_template, :format_encoders,\n      html: Phoenix.HTML.Engine","ref":"Phoenix.Template.html#module-format-encoders"},{"type":"macro","title":"Phoenix.Template.__using__/1","doc":"Ensure `__mix_recompile__?/0` will be defined.","ref":"Phoenix.Template.html#__using__/1"},{"type":"macro","title":"Phoenix.Template.compile_all/4","doc":"Compiles a function for each template in the given `root`.\n\n`converter` is an anonymous function that receives the template path\nand returns the function name (as a string).\n\nFor example, to compile all `.eex` templates in a given directory,\nyou might do:\n\n    Phoenix.Template.compile_all(\n      &(&1 |> Path.basename() |> Path.rootname(\".eex\")),\n      __DIR__,\n      \"*.eex\"\n    )\n\nIf the directory has templates named `foo.eex` and `bar.eex`,\nthey will be compiled into the functions `foo/1` and `bar/1`\nthat receive the template `assigns` as argument.\n\nYou may optionally pass a keyword list of engines. If a list\nis given, we will lookup and compile only this subset of engines.\nIf none is passed (`nil`), the default list returned by `engines/0`\nis used.","ref":"Phoenix.Template.html#compile_all/4"},{"type":"macro","title":"Phoenix.Template.embed_templates/2","doc":"A convenience macro for embeding templates as functions.\n\nThis macro is built on top of the more general `compile_all/3`\nfunctionality.","ref":"Phoenix.Template.html#embed_templates/2"},{"type":"macro","title":"Options - Phoenix.Template.embed_templates/2","doc":"* `:root` - The root directory to embed files. Defaults to the current\n    module's directory (`__DIR__`)\n  * `:suffix` - The string value to append to embedded function names. By\n    default, function names will be the name of the template file excluding\n    the format and engine.\n\nA wildcard pattern may be used to select all files within a directory tree.\nFor example, imagine a directory listing:\n\n    ├── pages\n    │   ├── about.html.heex\n    │   └── sitemap.xml.eex\n\nThen to embed the templates in your module:\n\n    defmodule MyAppWeb.Renderer do\n      import Phoenix.Template, only: [embed_templates: 1]\n      embed_templates \"pages/*\"\n    end\n\nNow, your module will have a `about/1` and `sitemap/1` functions.\nNote that functions across different formats were embedded. In case\nyou want to distinguish between them, you can give a more specific\npattern:\n\n    defmodule MyAppWeb.Emails do\n      import Phoenix.Template, only: [embed_templates: 2]\n\n      embed_templates \"pages/*.html\", suffix: \"_html\"\n      embed_templates \"pages/*.xml\", suffix: \"_xml\"\n    end\n\nNow the functions will be `about_html` and `sitemap_xml`.","ref":"Phoenix.Template.html#embed_templates/2-options"},{"type":"function","title":"Phoenix.Template.engines/0","doc":"Returns a keyword list with all template engines\nextensions followed by their modules.","ref":"Phoenix.Template.html#engines/0"},{"type":"function","title":"Phoenix.Template.find_all/3","doc":"Returns all template paths in a given template root.","ref":"Phoenix.Template.html#find_all/3"},{"type":"function","title":"Phoenix.Template.format_encoder/1","doc":"Returns the format encoder for the given template.","ref":"Phoenix.Template.html#format_encoder/1"},{"type":"function","title":"Phoenix.Template.hash/3","doc":"Returns the hash of all template paths in the given root.\n\nUsed by Phoenix to check if a given root path requires recompilation.","ref":"Phoenix.Template.html#hash/3"},{"type":"function","title":"Phoenix.Template.module_to_template_root/3","doc":"","ref":"Phoenix.Template.html#module_to_template_root/3"},{"type":"function","title":"Phoenix.Template.render/4","doc":"Renders template from module.\n\nFor a module called `MyApp.FooHTML` and template \"index.html.heex\",\nit will:\n\n  * First attempt to call `MyApp.FooHTML.index(assigns)`\n\n  * Then fallback to `MyApp.FooHTML.render(\"index.html\", assigns)`\n\n  * Raise otherwise\n\nIt expects the HTML module, the template as a string, the format, and a\nset of assigns.\n\nNotice that this function returns the inner representation of a\ntemplate. If you want the encoded template as a result, use\n`render_to_iodata/4` instead.","ref":"Phoenix.Template.html#render/4"},{"type":"function","title":"Examples - Phoenix.Template.render/4","doc":"Phoenix.Template.render(YourApp.UserView, \"index\", \"html\", name: \"John Doe\")\n    #=> {:safe, \"Hello John Doe\"}","ref":"Phoenix.Template.html#render/4-examples"},{"type":"function","title":"Assigns - Phoenix.Template.render/4","doc":"Assigns are meant to be user data that will be available in templates.\nHowever, there are keys under assigns that are specially handled by\nPhoenix, they are:\n\n  * `:layout` - tells Phoenix to wrap the rendered result in the\n    given layout. See next section","ref":"Phoenix.Template.html#render/4-assigns"},{"type":"function","title":"Layouts - Phoenix.Template.render/4","doc":"Templates can be rendered within other templates using the `:layout`\noption. `:layout` accepts a tuple of the form\n`{LayoutModule, \"template.extension\"}`.\n\nTo template that goes inside the layout will be placed in the `@inner_content`\nassign:\n\n    <%= @inner_content %>","ref":"Phoenix.Template.html#render/4-layouts"},{"type":"function","title":"Phoenix.Template.render_to_iodata/4","doc":"Renders the template and returns iodata.","ref":"Phoenix.Template.html#render_to_iodata/4"},{"type":"function","title":"Phoenix.Template.render_to_string/4","doc":"Renders the template to string.","ref":"Phoenix.Template.html#render_to_string/4"},{"type":"function","title":"Phoenix.Template.template_path_to_name/2","doc":"","ref":"Phoenix.Template.html#template_path_to_name/2"},{"type":"type","title":"Phoenix.Template.path/0","doc":"","ref":"Phoenix.Template.html#t:path/0"},{"type":"type","title":"Phoenix.Template.root/0","doc":"","ref":"Phoenix.Template.html#t:root/0"},{"type":"module","title":"Phoenix.Template.EExEngine","doc":"The Phoenix engine that handles the `.eex` extension.","ref":"Phoenix.Template.EExEngine.html"},{"type":"function","title":"Phoenix.Template.EExEngine.compile/2","doc":"","ref":"Phoenix.Template.EExEngine.html#compile/2"},{"type":"behaviour","title":"Phoenix.Template.Engine","doc":"Specifies the API for adding custom template engines into Phoenix.\n\nEngines must implement the `compile/2` function, that receives\nthe template file and the template name (usually used as the function\nname of the template) and outputs the template quoted expression:\n\n    def compile(template_path, template_name)\n\nSee `Phoenix.Template.EExEngine` for an example engine implementation.","ref":"Phoenix.Template.Engine.html"},{"type":"callback","title":"Phoenix.Template.Engine.compile/2","doc":"","ref":"Phoenix.Template.Engine.html#c:compile/2"},{"type":"module","title":"Phoenix.Template.ExsEngine","doc":"The Phoenix engine that handles the `.exs` extension.","ref":"Phoenix.Template.ExsEngine.html"},{"type":"function","title":"Phoenix.Template.ExsEngine.compile/2","doc":"","ref":"Phoenix.Template.ExsEngine.html#compile/2"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG","ref":"changelog.html"},{"type":"extras","title":"1.0.4 - CHANGELOG","doc":"* Relax Phoenix.HTML dependency","ref":"changelog.html#1-0-4"},{"type":"extras","title":"1.0.3 - CHANGELOG","doc":"* Improve error message for invalid file paths","ref":"changelog.html#1-0-3"},{"type":"extras","title":"1.0.2 - CHANGELOG","doc":"* Improve error message for missing templates","ref":"changelog.html#1-0-2"},{"type":"extras","title":"1.0.1 - CHANGELOG","doc":"* Add `embed_templates/2` for convenience","ref":"changelog.html#1-0-1"},{"type":"extras","title":"1.0.0 - CHANGELOG","doc":"* Initial release","ref":"changelog.html#1-0-0"}],"content_type":"text/markdown"}